music_xml library

Classes

Barline
Internal representation of a MusicXML <barline> element.
BeatsBeatType
ChordSymbol
Internal representation of a MusicXML chord symbol <harmony> element. This represents a chord symbol with four components:
Key
Internal representation of a MusicXML key signature.
Lyric
Internal representation of a MusicXML <lyric> element. https://www.w3.org/2021/06/musicxml40/musicxml-reference/elements/lyric/
LyricItem
Measure
Internal represention of the MusicXML <measure> element.
MusicXmlDocument
Internal representation of a MusicXML Document.
Note
Internal representation of a MusicXML <note> element. https://www.w3.org/2021/06/musicxml40/musicxml-reference/elements/note/
NoteDuration
Part
Internal represention of a MusicXML <part> element.
PartGroup
https://www.w3.org/2021/06/musicxml40/musicxml-reference/elements/part-group/
Print
https://www.w3.org/2021/06/musicxml40/musicxml-reference/elements/print/
Root
Internal representation of a MusicXML <root> element. https://www.w3.org/2021/06/musicxml40/musicxml-reference/elements/root/
ScorePart
Internal representation of a MusicXML <score-part>.
StartStopAttr
StepAlterAccidental
Tempo
Internal representation of a MusicXML tempo.
Tie
Internal representation of a MusicXML <tie> element. https://www.w3.org/2021/06/musicxml40/musicxml-reference/elements/tie/
Time
Internal representation of a MusicXML time signature. Does not support:

Extensions

SimpleKindExtension on Kind

Constants

chordKindAbbreviations → const Map<String, String>
The below dictionary maps chord kinds to an abbreviated string as would appear in a chord symbol in a standard lead sheet. There are often multiple standard abbreviations for the same chord type, e.g. "+" and "aug" both refer to an augmented chord, and "maj7", "M7", and a Delta character all refer to a major-seventh chord; this dictionary attempts to be consistent but the choice of abbreviation is somewhat arbitrary.
defaultQuartersPerMinute → const double
groupBarlineValueToString → const Map<GroupBarlineValue, String>
groupSymbolValueToString → const Map<GroupSymbolValue, String>
standardPpq → const int
Standard pulses per quarter. https://en.wikipedia.org/wiki/Pulses_per_quarter_note
startStopToString → const Map<StartStop, String>