Measure class
Internal represention of the MusicXML <measure> element.
https://www.w3.org/2021/06/musicxml40/musicxml-reference/elements/measure-partwise/
Constructors
-
Measure({required Number number, List<
Note> notes = const [], Iterable<Backup> backups = const [], Iterable<Forward> forwards = const [], Iterable<Direction> directions = const [], Iterable<Attributes> attributesList = const [], Iterable<ChordSymbol> chordSymbols = const [], Iterable<Print> prints = const [], Iterable<Barline> barlines = const [], Iterable<Tempo> tempos = const [], int duration = 0}) - Measure.parse(MusicXMLParserState state, XmlElement element)
-
Parse the
<measure>element.factory
Properties
-
attributes
→ XmlNodeList<
XmlAttribute> -
finalinherited
-
attributesList
→ Iterable<
Attributes> -
final
-
backups
→ Iterable<
Backup> -
final
-
barlines
→ Iterable<
Barline> -
final
-
childElements
→ Iterable<
XmlElement> -
Return an Iterable over the
XmlElementchildren of this node.no setterinherited -
children
→ XmlNodeList<
XmlNode> -
finalinherited
-
chordSymbols
→ Iterable<
ChordSymbol> -
final
-
directions
→ Iterable<
Direction> -
final
- duration → int
-
final
- firstChild → XmlNode?
-
Return the first child of this node, or
nullif there are no children.no setterinherited - firstElementChild → XmlElement?
-
Return the first child
XmlElement, ornullif there are none.no setterinherited -
forwards
→ Iterable<
Forward> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasParent → bool
-
Test whether the node has a parent or not.
no setterinherited
- isSelfClosing ↔ bool
-
Defines whether the element should be self-closing when empty.
getter/setter pairinherited
- lastChild → XmlNode?
-
Return the last child of this node, or
nullif there are no children.no setterinherited - lastElementChild → XmlElement?
-
Return the last child
XmlElement, ornullif there are none.no setterinherited - localName → String
-
Return the local name, excluding the namespace prefix.
no setterinherited
- name → XmlName
-
finalinherited
- namespacePrefix → String?
-
Return the namespace prefix, or
null.no setterinherited - namespaceUri → String?
-
Return the namespace URI, or
null.no setterinherited - nodeType → XmlNodeType
-
Return the node type of this node.
no setterinherited
-
notes
→ List<
Note> -
final
- number ↔ Number
-
getter/setter pair
- parent → XmlNode?
-
Return the parent node of this node, or
nullif there is none.no setterinherited -
prints
→ Iterable<
Print> -
final
- qualifiedName → String
-
Return the fully qualified name, including the namespace prefix.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
tempos
→ Iterable<
Tempo> -
final
- text → String
-
Returns the concatenated text of this node or its descendants, for
text, CDATA, and comment nodes return the textual value of the node.
no setterinherited
- value → String?
-
Returns the value of the node, or
null.no setterinherited
Methods
-
accept(
XmlVisitor visitor) → void -
Dispatch the invocation depending on this type to the
visitor.inherited -
attachParent(
covariant XmlNode parent) → void -
Internal helper to attach a child to this parent, do not call directly.
inherited
-
copy(
) → XmlElement -
Return a copy of this node and all its children.
inherited
-
detachParent(
covariant XmlNode parent) → void -
Internal helper to detach a child from its parent, do not call directly.
inherited
-
getAttribute(
String name, {String? namespace}) → String? -
Return the attribute value with the given
name, ornull.inherited -
getAttributeNode(
String name, {String? namespace}) → XmlAttribute? -
Return the attribute node with the given
name, ornull.inherited -
getElement(
String name, {String? namespace}) → XmlElement? -
Return the first child element with the given
name, ornull.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeAttribute(
String name, {String? namespace}) → void -
Removes the attribute value with the given fully qualified
name.inherited -
setAttribute(
String name, String? value, {String? namespace}) → void -
Set the attribute value with the given fully qualified
nametovalue. If an attribute with the name already exist, its value is updated. If the value isnull, the attribute is removed.inherited -
toString(
) → String -
A string representation of this object.
inherited
-
toXmlString(
{bool pretty = false, XmlEntityMapping? entityMapping, int? level, String? indent, String? newLine, Predicate< XmlNode> ? preserveWhitespace, Predicate<XmlAttribute> ? indentAttribute, Comparator<XmlAttribute> ? sortAttributes, Predicate<XmlNode> ? spaceBeforeSelfClose}) → String -
Return an XML string of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited