NoteTypeValue enum
https://www.w3.org/2021/06/musicxml40/musicxml-reference/data-types/note-type-value/
The graphic note type, from 1024th (shortest) to maxima (longest).
Names that start with a digit in MusicXML get an n prefix here, since
Dart identifiers can not start with a digit.
Values
- n1024th → const NoteTypeValue
- n512th → const NoteTypeValue
- n256th → const NoteTypeValue
- n128th → const NoteTypeValue
- n64th → const NoteTypeValue
- n32nd → const NoteTypeValue
- n16th → const NoteTypeValue
- eighth → const NoteTypeValue
- quarter → const NoteTypeValue
- half → const NoteTypeValue
- whole → const NoteTypeValue
- breve → const NoteTypeValue
- long → const NoteTypeValue
- maxima → const NoteTypeValue
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
NoteTypeValue> - A constant List of the values in this enum, in order of their declaration.